==> escapework-manager-2.0.0-90a810.tar: resources/views/roles/form.blade.php <==
<fieldset>
    {!! Form::hidden('id', $role->id) !!}

    <div class="form-group">
        {!! Form::label('title', trans('manager::roles.label.title'), ['class' => 'col-sm-2 control-label']) !!}

        <div class="col-sm-4">
            {!! Form::text('title', $role->title, ['required' => 'true', 'autofocus' => 'true', 'id' => 'title', 'class' => 'form-control']) !!}
        </div>
    </div><!-- .form-group -->

    <div class="form-group">
        {!! Form::label('all_permissions', trans('manager::roles.label.all_permissions'), ['class' => 'col-sm-3 control-label']) !!}

        <div class="col-sm-8">
            <div class="inline radio">
                <label>
                    <input type="radio" name="all_permissions" value="1" {{ $role->all_permissions ? 'checked="checked"' : null }}>
                    {{ trans('manager::roles.label.yes') }}
                </label>
            </div>

            <div class="inline radio">
                <label>
                    <input type="radio" name="all_permissions" value="0" {{ ! $role->all_permissions ? 'checked="checked"' : null }}>
                    {{ trans('manager::roles.label.no') }}
                </label>
            </div>
        </div>
    </div><!-- .form-group -->
</fieldset>

<hr>

<fieldset id="box-permissions">
    <legend>{{ trans('manager::roles.form.permissions.title') }}</legend>

    @foreach (config('manager.permissions.pages') as $slug => $page)
        <div class="form-group">
            <label class="col-sm-2 control-label">{{ $page['title'] }}</label>

            <div class="col-sm-8 js-controls-permissions">
                <div class="checkbox">
                    <label>
                        <input type="checkbox" name="pages[]" value="{{ $slug }}">
                        {{ trans('manager::roles.form.permissions.guarantee-page') }}
                    </label>
                </div><!-- .checkbox -->

                {{--
                @if ($page->actions->count() > 0)
                    <br>

                    @foreach ($page->actions as $action)
                        <div class="checkbox">
                            <label>
                                <input type="checkbox" name="actions[{{ $page->id }}][]" value="{{ $action->id }}" {{ $role->actions->contains($action->id) ? 'checked="checked"' : null }}>
                                <strong>{{ $action->title }}</strong> <small>({{ trans('manager::roles.form.permissions.guarantee-action') }} <strong>{{ $page->title }}</strong>)</small>
                            </label>
                        </div>
                    @endforeach
                @endif
                --}}
            </div><!-- .controls -->
        </div><!-- .form-group -->
    @endforeach
</fieldset>

<hr>

<div class="form-group">
    <div class="col-sm-offset-2 col-sm-10">
        <button type="submit" class="btn btn-primary js-btn-submit" data-loading-text="{{ trans('manager::roles.btn.loading') }}">{{ trans('manager::roles.btn.submit') }}</button>
        <a href="{{ route('manager.roles.index') }}" class="btn">{{ trans('manager::roles.btn.cancel') }}</a>
    </div><!-- .form-actions -->
</div>

@section('scripts')
    @parent

    <script type="text/javascript">
    (function() {
        $('#form-role').on('submit', function(e) {
            $(this).find('.js-btn-submit').button('loading');
        });
    })();
    </script>
@stop

==> escapework-manager-4.2.4-3b065a.tar: resources/views/roles/form.blade.php <==
<fieldset>
    {!! Form::hidden('id', $role->id) !!}

    <div class="form-group">
        {!! Form::label('title', trans('manager::roles.label.title'), ['class' => 'col-sm-2 control-label']) !!}

        <div class="col-sm-4">
            {!! Form::text('title', $role->title, ['required' => 'true', 'autofocus' => 'true', 'id' => 'title', 'class' => 'form-control']) !!}
        </div>
    </div><!-- .form-group -->

    <div class="form-group">
        {!! Form::label('all_permissions', trans('manager::roles.label.all_permissions'), ['class' => 'col-sm-3 control-label']) !!}

        <div class="col-sm-8">
            <div class="inline radio">
                <label>
                    <input type="radio" name="all_permissions" value="1" {{ $role->all_permissions ? 'checked="checked"' : null }}>
                    {{ trans('manager::roles.label.yes') }}
                </label>
            </div>

            <div class="inline radio">
                <label>
                    <input type="radio" name="all_permissions" value="0" {{ ! $role->all_permissions ? 'checked="checked"' : null }}>
                    {{ trans('manager::roles.label.no') }}
                </label>
            </div>
        </div>
    </div><!-- .form-group -->
</fieldset>

<hr>

<fieldset id="box-permissions">
    <legend>Permissões</legend>

    @foreach ($pages->all() as $slug => $page)
        <div class="form-group">
            <label class="col-sm-2 control-label">{{ $page['title'] }}</label>

            <div class="col-sm-8 js-controls-permissions">
                <div class="checkbox">
                    <label>
                        <input type="checkbox" name="pages[]" value="{{ $slug }}" {!! $role->pages->contains('page', $slug) ? 'checked="true"' : null !!}>
                        Dar permissão de acesso
                    </label>
                </div><!-- .checkbox -->

                @if (count($page['actions']) > 0)
                    <div style="padding-left: 20px;">
                        @foreach ($page['actions'] as $action => $title)
                            <div class="checkbox">
                                <label>
                                    <input type="checkbox" name="actions[{{ $slug }}][]" value="{{ $action }}" {{ $role->actions->hasAction($slug, $action) ? 'checked="checked"' : null }}>
                                    <strong>{{ $title }}</strong> <small>({{ trans('manager::roles.form.permissions.guarantee-action') }} <strong>{{ $page['title'] }}</strong>)</small>
                                </label>
                            </div>
                        @endforeach
                    </div>
                @endif
            </div><!-- .controls -->
        </div><!-- .form-group -->
    @endforeach
</fieldset>

<hr>

<div class="form-group">
    <div class="col-sm-offset-2 col-sm-10">
        <button type="submit" class="btn btn-primary js-btn-submit" data-loading-text="{{ trans('manager::roles.btn.loading') }}">{{ trans('manager::roles.btn.submit') }}</button>
        <a href="{{ route('manager.roles.index') }}" class="btn">{{ trans('manager::roles.btn.cancel') }}</a>
    </div><!-- .form-actions -->
</div>

@section('scripts')
    @parent

    <script type="text/javascript">
    (function() {
        $('#form-role').on('submit', function(e) {
            $(this).find('.js-btn-submit').button('loading');
        });
    })();
    </script>
@stop
